@@ -12,9 +12,7 @@ For usage information, run `sntools -h` or `python sntools/genevts.py -h`.
 For more extensive documentation, to report issues or to contribute code,
 see https://github.com/JostMigenda/sntools.
 """
-from __future__ import print_function
-
-__version__ = '0.7.4'
+__version__ = '1.0.1'
 
 
 def setup():
@@ -39,10 +37,8 @@ def setup():
         print("Downloading sample flux file from " + flux_url)
         if not os.path.isdir(flux_dir):
             os.mkdir(flux_dir)
-        try:
-            from urllib.request import urlretrieve  # Python 3.x
-        except ImportError:
-            from urllib import urlretrieve  # Python 2.7
+
+        from urllib.request import urlretrieve
         try:
             urlretrieve(flux_url, filename=flux_file)
             tryprint(u"\u2705", "[SUCCESS]")
@@ -54,15 +50,15 @@ def setup():
 
     tryprint(u"\U0001f6e0")
     print("Testing event generation ...")
-    sys.argv += [flux_file, '--format', 'nakazato', '--detector', 'WATCHMAN-LS', '--distance', '2', '--ordering', 'normal', '--starttime', '100', '--endtime', '300', '-o', 'outfile.kin', '--randomseed', '314']
+    sys.argv += [flux_file, '--format', 'nakazato', '--detector', 'WATCHMAN-LS', '--distance', '2', '--transformation', 'AdiabaticMSW_NMO', '--starttime', '100', '--endtime', '300', '-o', 'outfile.kin', '--randomseed', '314']
     genevts.main()
 
     tryprint(u"\U0001f6e0")
     print("Checking output file ...")
-    with open('outfile.kin', 'rb') as f:
-        output_sha = hashlib.sha256(f.read()).hexdigest()
+    with open('outfile.kin', 'r') as f:
+        output_sha = hashlib.sha256(f.read().encode('utf-8')).hexdigest()
 
-    test_sha = "8bdd9308e866076aeae2f01272a9b3025f438e2d727698da0714cf931ff556d6"
+    test_sha = "4424b738d32b6c4baa459fb6fb76d63f944b572a02d319bde4fd247a520f1e29"
     if output_sha == test_sha:
         tryprint(u"\u2705", "[SUCCESS]")
         print("Everything seems to work fine. Enjoy using sntools!")
